@@ -231,6 +231,9 @@ void show_select_game_dialog (void)
 
     g_object_unref (files);
 
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list),
+					  0, GTK_SORT_ASCENDING);
+
     gtk_dialog_set_default_response ( GTK_DIALOG (dialog), GTK_RESPONSE_OK );
 
     g_signal_connect (G_OBJECT (dialog), "response", 
@@ -391,86 +394,6 @@ void show_preferences_dialog ()
   gtk_window_present (GTK_WINDOW (property_box));
 }
 
-#if 0
-
-SCM options = SCM_BOOL_F;
-GtkWidget *option_page;
-
-static void 
-option_apply (GtkWidget *w, int response)
-{
-    SCM opts = options;
-    GList *item = GTK_BOX (option_page)->children;
-    
-		if ( response != GTK_RESPONSE_OK )
-			return;
-		
-    for(; opts != SCM_EOL; item = item->next, opts = SCM_CDR (opts)) {
-      
-      SCM_SETCAR (SCM_CDAR(opts), 
-		  SCM_BOOL (GTK_TOGGLE_BUTTON 
-			    (((GtkBoxChild *) item->data)->widget)->active));
-    }    
-    cscmi_apply_options_lambda (options);
-}
-
-static GtkWidget *
-get_option_page (GtkWidget* option_dialog)
-{
-  SCM opts;
-  GtkWidget* vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
-
-  for(opts = options; opts != SCM_EOL; opts = SCM_CDR (opts)) {
-    GtkWidget *toggle = 
-      gtk_check_button_new_with_label (_(SCM_STRING_CHARS (SCM_CAAR(opts))));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), 
-				 SCM_NFALSEP(SCM_CADAR(opts)));
-    gtk_box_pack_end (GTK_BOX (vbox), toggle, 
-		      FALSE, FALSE, GNOME_PAD_SMALL);
-  }
-  return vbox;
-}
-
-void show_rules_options_dialog () 
-{
-	static GtkWidget *notebook = NULL;
-  /* Need to call this every time as it might be garbage collected ! */
-	options = cscmi_get_options_lambda ();
-  
-  if (!option_dialog && SCM_NFALSEP(options)) {
-    option_dialog = gtk_dialog_new ();
-    gtk_dialog_set_has_separator (GTK_DIALOG (option_dialog), FALSE);
-		notebook = gtk_notebook_new();
-
-		gtk_container_add (GTK_CONTAINER(GTK_DIALOG(option_dialog)->vbox),
-		                   notebook);
-		
-		gtk_dialog_add_buttons(GTK_DIALOG(option_dialog),
-		                       GTK_STOCK_OK,
-				       GTK_RESPONSE_OK,
-				       GTK_STOCK_CANCEL,
-				       GTK_RESPONSE_CANCEL, NULL);
-
-    gtk_window_set_transient_for (GTK_WINDOW (option_dialog), GTK_WINDOW (app));
-		gtk_window_set_modal(GTK_WINDOW(option_dialog), TRUE);
- 
-    option_page = get_option_page(option_dialog);
-
-		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), 
-				      option_page, 
-				      gtk_label_new(game_name));
-
-    g_signal_connect (GTK_OBJECT (option_dialog), "response",
-			GTK_SIGNAL_FUNC (option_apply), NULL);
-
-    g_signal_connect (GTK_OBJECT (option_dialog), "delete_event",
-			GTK_SIGNAL_FUNC (gtk_widget_hide), NULL);
-  } 
-  gtk_window_present (GTK_WINDOW (option_dialog));
-}
-
-#endif
-
 void show_global_stats_dialog () 
 {
 }
