@@ -48,26 +48,6 @@ GtkWidget *helpitem;
 GtkWidget *menubar;
 GtkWidget *toolbar;
 
-static gchar * gamename = NULL;
-static gchar * ugamename = NULL;
-
-static gchar *convert_name_to_underscored (const gchar *inname)
-{
-  gchar *outname;
-  gchar *s;
-
-  outname = g_strdup (inname);
-
-  s = outname;
-  while (*s) {
-    if (*s == ' ')
-      *s = '_';
-    s++;
-  }
-
-  return outname;
-}
-
 static void restart_game ()
 {
   if (waiting_for_mouse_up()) return;
@@ -136,7 +116,7 @@ static void help_about_callback (void)
 			 "authors", authors,
 			 "documenters", documenters,
 			 "translator_credits", _("translator-credits"),
-			 "logo-icon-name", "gnome-aisleriot.png",
+			 "logo-icon-name", "gnome-aisleriot",
 			 "website", "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE,
 			 NULL);
@@ -150,8 +130,12 @@ static void general_help (void)
 
 static void help_on_specific_game (void)
 {
-  gnome_help_display_on_screen ("aisleriot.xml", ugamename,
-				gtk_widget_get_screen (app), NULL);
+  gchar *help_section;
+  
+  help_section = game_file_to_help_section (game_file);
+  gnome_help_display_on_screen ("aisleriot.xml", help_section,
+ 				gtk_widget_get_screen (app), NULL);
+  g_free (help_section);
 }
 
 static void toolbar_toggle_callback(GtkToggleAction * togglebutton, 
@@ -235,8 +219,8 @@ static const GtkActionEntry actions[] = {
   { "OptionsMenu", NULL, "Options" /* not translated on purpose */ },
   { "HelpMenu", NULL, N_("_Help") },
 
-  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (new_game_action) },
-  { "RestartGame", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL, G_CALLBACK (restart_game) },
+  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, N_("Start a new game"), G_CALLBACK (new_game_action) },
+  { "RestartGame", GAMES_STOCK_RESTART_GAME, NULL, NULL, N_("Restart the current game"), G_CALLBACK (restart_game) },
   { "Select", GTK_STOCK_INDEX, N_("_Select Game..."), "<Ctrl>o", N_("Play a different game"), G_CALLBACK (show_select_game_dialog) },
   { "Statistics", GTK_STOCK_ADD, N_("S_tatistics"), NULL, N_("Show gameplay statistics"), G_CALLBACK (show_statistics_dialog) },
   { "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_app) },
@@ -244,9 +228,9 @@ static const GtkActionEntry actions[] = {
   { "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_callback) },
   { "Cards", NULL, N_("_Cards..."), NULL, NULL, G_CALLBACK (show_preferences_dialog) },
 
-  { "UndoMove", GAMES_STOCK_UNDO_MOVE, NULL, NULL, NULL, G_CALLBACK (undo_callback) },
-  { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL, NULL, G_CALLBACK (redo_callback) },
-  { "Hint", GAMES_STOCK_HINT, NULL, NULL, NULL, G_CALLBACK (show_hint_dialog) },
+  { "UndoMove", GAMES_STOCK_UNDO_MOVE, NULL, NULL, N_("Undo the last move"), G_CALLBACK (undo_callback) },
+  { "RedoMove", GAMES_STOCK_REDO_MOVE, NULL, NULL, N_("Redo the last move"), G_CALLBACK (redo_callback) },
+  { "Hint", GAMES_STOCK_HINT, NULL, NULL, N_("Show a hint"), G_CALLBACK (show_hint_dialog) },
   { "Contents", GAMES_STOCK_CONTENTS, NULL, NULL, N_("View help for Aisleriot"), G_CALLBACK (general_help) },
   { "Help", GTK_STOCK_HELP, NULL, "<Shift>F1", N_("View help for this game"), G_CALLBACK (help_on_specific_game) },
   { "About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (help_about_callback) },
@@ -351,20 +335,9 @@ void create_menus ()
   set_fullscreen_actions (FALSE);
 }
 
-void help_update_game_name (gchar * name)
+void help_update_game_name ()
 {
-
-  if (gamename)
-    g_free (gamename);
-
-  if (ugamename)
-    g_free (ugamename);
-
-  gamename = g_strdup (name);
-  ugamename = convert_name_to_underscored (name);
-
-  gtk_label_set_text (GTK_LABEL (GTK_BIN (helpitem)->child), gamename);
-
+  gtk_label_set_text (GTK_LABEL (GTK_BIN (helpitem)->child), game_name);
 }
 
 static gchar * make_option_gconf_key (void)
@@ -374,8 +347,7 @@ static gchar * make_option_gconf_key (void)
   GConfSchema *schema;
   GConfValue *def;
     
-  r = g_strconcat (basekey, ugamename, NULL);
-
+  r = g_strconcat (basekey, game_file, NULL);
   sk = g_strconcat ("/schemas", r, NULL);
 
   /* Check if we have a schema for this key and make one if we don't. */
@@ -507,7 +479,7 @@ enum {
  * another atom. The exact value of the atoms is irrelevant - they merely
  * trigger a toggle - but descriptive names like begin-exclusive and
  * end-exclusive are probably a good idea. */
-void install_options_menu (gchar *name)
+void install_options_menu ()
 {
   static int merge_id = 0;
   static GtkActionGroup *options_group = NULL;
@@ -528,8 +500,7 @@ void install_options_menu (gchar *name)
 
   if (cscmi_has_options ()) {
     menuaction = gtk_action_group_get_action (action_group, "OptionsMenu");
-    g_object_set (G_OBJECT (menuaction), "label", name, NULL);
-
+    g_object_set (G_OBJECT (menuaction), "label", game_name, NULL);
     options_group = gtk_action_group_new ("OptionsActions");
     gtk_ui_manager_insert_action_group (ui_manager, options_group, -1);
     g_object_unref (options_group);
