@@ -40,7 +40,7 @@ extern Prefs p;
 Theme theme[] = {
 	{
 		N_("Classic"),
-		"tileset_50x50_classic.png",
+		"tileset_50x50_sunspot.svg",
 		NULL,
 		"#9999CC",
 		DEFAULT_GRID_STYLE,
@@ -48,14 +48,22 @@ Theme theme[] = {
 	},
 	{
 		N_("High Contrast"),
-		"tileset_50x50_hcontrast.png",
-		"bg_toplight.png",
+		"tileset_50x50_hcontrast.svg",
+		NULL,
+		"#000000",
+		DEFAULT_GRID_STYLE,
+		N_("Light"), N_("Dark")
+	},
+	{
+		N_("High Contrast Inverse"),
+		"tileset_50x50_hcinverse.svg",
+		NULL,
 		"#FFFFFF",
 		DEFAULT_GRID_STYLE,
 		N_("Light"), N_("Dark")
 	},
 	{
-		N_("Marbles"),
+		N_("Cream Marbles"),
 		"tileset_50x50_catseyes.png",
 		"bg_toplight.png",
 		"#727F8C",
@@ -63,7 +71,7 @@ Theme theme[] = {
 		N_("Red"), N_("Blue")
 	},
 	{
-		N_("More Marbles"),
+		N_("Glass Marbles"),
 		"tileset_50x50_glassy.png",
 		"bg_grotty.jpg",
 		"#727F8C",
@@ -72,7 +80,7 @@ Theme theme[] = {
 	},
 	{
 		N_("Nightfall"),
-		"tileset_50x50_classic.png",
+		"tileset_50x50_glassy.png",
 		"bg_nightfall.jpg",
 		"#727F8C",
 		DEFAULT_GRID_STYLE,
