@@ -230,7 +230,7 @@ GList *games_scores_backend_get_scores (GamesScoresBackend *self)
   return self->scores_list;
 }
 
-void games_scores_backend_set_scores (GamesScoresBackend *self,
+gboolean games_scores_backend_set_scores (GamesScoresBackend *self,
 				      GList *list)
 {
     GList *s;
@@ -240,7 +240,7 @@ void games_scores_backend_set_scores (GamesScoresBackend *self,
     gchar dtostrbuf[G_ASCII_DTOSTR_BUF_SIZE];
 
     if (!games_scores_backend_get_lock (self))
-      return;
+      return FALSE;
 
     self->scores_list = list;
 
@@ -285,6 +285,7 @@ void games_scores_backend_set_scores (GamesScoresBackend *self,
 
     games_scores_backend_release_lock (self);
 
+	return TRUE;
  }
 
 void games_scores_backend_discard_scores (GamesScoresBackend *self)
