@@ -51,7 +51,7 @@ gint theme_index_counter;
 /* All quit events must go through here to ensure consistant behaviour. */
 static void quit_cb (void)
 {
-	// need mutex on game_state to avoid funky save data?
+	/* need mutex on game_state to avoid funky save data? */
 	save_game ();
   
 	gtk_main_quit ();
@@ -104,14 +104,21 @@ static void about_cb (GtkWidget *widget)
 {
   const gchar * const authors[] = { "Callum McKenzie", NULL };
   
+  const gchar * const documenters[] = { "Callum McKenzie", NULL };
+  
   gtk_show_about_dialog (GTK_WINDOW (application),
-			 "authors", authors,
-			 "comments", _("I want to play that game! You know, they all go whirly-round and you click on them and they vanish!"),
-			 "copyright", "Copyright \xc2\xa9 2004 Callum McKenzie",
-			 "name", _(APPNAME_LONG),
-			 "translator_credits", _("translator-credits"),
-			 "version", VERSION,
-			 NULL);
+												 "authors", authors,
+												 "documenters", documenters,
+												 "comments", _("I want to play that game! You know, they all go whirly-round and you click on them and they vanish!"),
+												 "copyright", "Copyright \xc2\xa9 2006 Callum McKenzie",
+												 "license", "GPL 2+",
+												 "name", _(APPNAME_LONG),
+												 "translator_credits", _("translator-credits"),
+												 "version", VERSION,
+												 "logo-icon-name", "gnome-same-gnome",	 
+												 "website", "http://www.gnome.org/projects/gnome-games/",
+												 "wrap-license", TRUE,
+												 NULL);
 }
 
 static GtkWidget *generate_scores_dialog (void)
@@ -481,8 +488,7 @@ void build_gui (void)
   GtkUIManager *ui_manager;
   GtkActionGroup *action_group;
   
-	/* FIXME: Can we get a better name for the icon? */
-	gtk_window_set_default_icon_name ("gnome-gsame");
+	gtk_window_set_default_icon_name ("gnome-same-gnome");
 
   application = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (application), _(APPNAME_LONG));
